Class: Google::Apis::MerchantapiReportsV1beta::NonProductPerformanceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Fields available for query in non_product_performance_view table. Performance data on images and online store links leading to your non-product pages. This includes performance metrics (for example, clicks) and dimensions according to which performance metrics are segmented (for example, date). Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for fields requested explicitly in the request's search query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NonProductPerformanceView

Returns a new instance of NonProductPerformanceView.



774
775
776
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#click_through_rateFloat

Click-through rate - the number of clicks (clicks) divided by the number of impressions (impressions) of images and online store links leading to your non-product pages. Metric. Corresponds to the JSON property clickThroughRate

Returns:

  • (Float)


736
737
738
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 736

def click_through_rate
  @click_through_rate
end

#clicksFixnum

Number of clicks on images and online store links leading to your non-product pages. Metric. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


742
743
744
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 742

def clicks
  @clicks
end

#dateGoogle::Apis::MerchantapiReportsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



754
755
756
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 754

def date
  @date
end

#impressionsFixnum

Number of times images and online store links leading to your non-product pages were shown. Metric. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


760
761
762
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 760

def impressions
  @impressions
end

#weekGoogle::Apis::MerchantapiReportsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property week



772
773
774
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 772

def week
  @week
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



779
780
781
782
783
784
785
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 779

def update!(**args)
  @click_through_rate = args[:click_through_rate] if args.key?(:click_through_rate)
  @clicks = args[:clicks] if args.key?(:clicks)
  @date = args[:date] if args.key?(:date)
  @impressions = args[:impressions] if args.key?(:impressions)
  @week = args[:week] if args.key?(:week)
end