Class: Google::Apis::MerchantapiReportsV1beta::PriceInsightsProductView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Fields available for query in price_insights_product_view table. Price insights report. Values are only set for fields requested explicitly in the request's search query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PriceInsightsProductView

Returns a new instance of PriceInsightsProductView.



1070
1071
1072
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#brandString

Brand of the product. Corresponds to the JSON property brand

Returns:

  • (String)


955
956
957
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 955

def brand
  @brand
end

#category_l1String

Product category (1st level) in Google's product taxonomy. Corresponds to the JSON property categoryL1

Returns:

  • (String)


961
962
963
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 961

def category_l1
  @category_l1
end

#category_l2String

Product category (2nd level) in Google's product taxonomy. Corresponds to the JSON property categoryL2

Returns:

  • (String)


967
968
969
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 967

def category_l2
  @category_l2
end

#category_l3String

Product category (3rd level) in Google's product taxonomy. Corresponds to the JSON property categoryL3

Returns:

  • (String)


973
974
975
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 973

def category_l3
  @category_l3
end

#category_l4String

Product category (4th level) in Google's product taxonomy. Corresponds to the JSON property categoryL4

Returns:

  • (String)


979
980
981
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 979

def category_l4
  @category_l4
end

#category_l5String

Product category (5th level) in Google's product taxonomy. Corresponds to the JSON property categoryL5

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 985

def category_l5
  @category_l5
end

#effectivenessString

The predicted effectiveness of applying the price suggestion, bucketed. Corresponds to the JSON property effectiveness

Returns:

  • (String)


990
991
992
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 990

def effectiveness
  @effectiveness
end

#idString

REST ID of the product, in the form of channel~languageCode~feedLabel~offerId . Can be used to join data with the product_view table. Required in the SELECT clause. Corresponds to the JSON property id

Returns:

  • (String)


997
998
999
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 997

def id
  @id
end

#offer_idString

Merchant-provided id of the product. Corresponds to the JSON property offerId

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1002

def offer_id
  @offer_id
end

#predicted_clicks_change_fractionFloat

Predicted change in clicks as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in clicks. Corresponds to the JSON property predictedClicksChangeFraction

Returns:

  • (Float)


1009
1010
1011
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1009

def predicted_clicks_change_fraction
  @predicted_clicks_change_fraction
end

#predicted_conversions_change_fractionFloat

Predicted change in conversions as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in conversions). Corresponds to the JSON property predictedConversionsChangeFraction

Returns:

  • (Float)


1016
1017
1018
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1016

def predicted_conversions_change_fraction
  @predicted_conversions_change_fraction
end

#predicted_impressions_change_fractionFloat

Predicted change in impressions as a fraction after introducing the suggested price compared to current active price. For example, 0.05 is a 5% predicted increase in impressions. Corresponds to the JSON property predictedImpressionsChangeFraction

Returns:

  • (Float)


1023
1024
1025
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1023

def predicted_impressions_change_fraction
  @predicted_impressions_change_fraction
end

#priceGoogle::Apis::MerchantapiReportsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property price



1028
1029
1030
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1028

def price
  @price
end

#product_type_l1String

Product type (1st level) in merchant's own product taxonomy. Corresponds to the JSON property productTypeL1

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1034

def product_type_l1
  @product_type_l1
end

#product_type_l2String

Product type (2nd level) in merchant's own product taxonomy. Corresponds to the JSON property productTypeL2

Returns:

  • (String)


1040
1041
1042
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1040

def product_type_l2
  @product_type_l2
end

#product_type_l3String

Product type (3rd level) in merchant's own product taxonomy. Corresponds to the JSON property productTypeL3

Returns:

  • (String)


1046
1047
1048
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1046

def product_type_l3
  @product_type_l3
end

#product_type_l4String

Product type (4th level) in merchant's own product taxonomy. Corresponds to the JSON property productTypeL4

Returns:

  • (String)


1052
1053
1054
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1052

def product_type_l4
  @product_type_l4
end

#product_type_l5String

Product type (5th level) in merchant's own product taxonomy. Corresponds to the JSON property productTypeL5

Returns:

  • (String)


1058
1059
1060
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1058

def product_type_l5
  @product_type_l5
end

#suggested_priceGoogle::Apis::MerchantapiReportsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property suggestedPrice



1063
1064
1065
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1063

def suggested_price
  @suggested_price
end

#titleString

Title of the product. Corresponds to the JSON property title

Returns:

  • (String)


1068
1069
1070
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1068

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1075

def update!(**args)
  @brand = args[:brand] if args.key?(:brand)
  @category_l1 = args[:category_l1] if args.key?(:category_l1)
  @category_l2 = args[:category_l2] if args.key?(:category_l2)
  @category_l3 = args[:category_l3] if args.key?(:category_l3)
  @category_l4 = args[:category_l4] if args.key?(:category_l4)
  @category_l5 = args[:category_l5] if args.key?(:category_l5)
  @effectiveness = args[:effectiveness] if args.key?(:effectiveness)
  @id = args[:id] if args.key?(:id)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @predicted_clicks_change_fraction = args[:predicted_clicks_change_fraction] if args.key?(:predicted_clicks_change_fraction)
  @predicted_conversions_change_fraction = args[:predicted_conversions_change_fraction] if args.key?(:predicted_conversions_change_fraction)
  @predicted_impressions_change_fraction = args[:predicted_impressions_change_fraction] if args.key?(:predicted_impressions_change_fraction)
  @price = args[:price] if args.key?(:price)
  @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1)
  @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2)
  @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3)
  @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4)
  @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5)
  @suggested_price = args[:suggested_price] if args.key?(:suggested_price)
  @title = args[:title] if args.key?(:title)
end