Class: Google::Apis::MerchantapiReportsV1beta::ProductPerformanceView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Fields available for query in product_performance_view table. Product performance data for your account, including performance metrics (for example, clicks) and dimensions according to which performance metrics are segmented ( for example, offer_id). Values of product dimensions, such as offer_id, reflect the state of a product at the time of the impression. Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for fields requested explicitly in the request's search query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductPerformanceView

Returns a new instance of ProductPerformanceView.



1346
1347
1348
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#brandString

Brand of the product. Segment. Corresponds to the JSON property brand

Returns:

  • (String)


1160
1161
1162
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1160

def brand
  @brand
end

#category_l1String

Product category (1st level) in Google's product taxonomy. Segment. Corresponds to the JSON property categoryL1

Returns:

  • (String)


1167
1168
1169
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1167

def category_l1
  @category_l1
end

#category_l2String

Product category (2nd level) in Google's product taxonomy. Segment. Corresponds to the JSON property categoryL2

Returns:

  • (String)


1174
1175
1176
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1174

def category_l2
  @category_l2
end

#category_l3String

Product category (3rd level) in Google's product taxonomy. Segment. Corresponds to the JSON property categoryL3

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1181

def category_l3
  @category_l3
end

#category_l4String

Product category (4th level) in Google's product taxonomy. Segment. Corresponds to the JSON property categoryL4

Returns:

  • (String)


1188
1189
1190
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1188

def category_l4
  @category_l4
end

#category_l5String

Product category (5th level) in Google's product taxonomy. Segment. Corresponds to the JSON property categoryL5

Returns:

  • (String)


1195
1196
1197
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1195

def category_l5
  @category_l5
end

#click_through_rateFloat

Click-through rate - the number of clicks merchant's products receive (clicks) divided by the number of times the products are shown (impressions). Metric. Corresponds to the JSON property clickThroughRate

Returns:

  • (Float)


1201
1202
1203
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1201

def click_through_rate
  @click_through_rate
end

#clicksFixnum

Number of clicks. Metric. Corresponds to the JSON property clicks

Returns:

  • (Fixnum)


1206
1207
1208
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1206

def clicks
  @clicks
end

#conversion_rateFloat

Number of conversions divided by the number of clicks, reported on the impression date. Metric. Available only for the FREE traffic source. Corresponds to the JSON property conversionRate

Returns:

  • (Float)


1212
1213
1214
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1212

def conversion_rate
  @conversion_rate
end

#conversion_valueGoogle::Apis::MerchantapiReportsV1beta::Price

The price represented as a number and currency. Corresponds to the JSON property conversionValue



1217
1218
1219
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1217

def conversion_value
  @conversion_value
end

#conversionsFloat

Number of conversions attributed to the product, reported on the conversion date. Depending on the attribution model, a conversion might be distributed across multiple clicks, where each click gets its own credit assigned. This metric is a sum of all such credits. Metric. Available only for the FREE traffic source. Corresponds to the JSON property conversions

Returns:

  • (Float)


1226
1227
1228
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1226

def conversions
  @conversions
end

#custom_label0String

Custom label 0 for custom grouping of products. Segment. Corresponds to the JSON property customLabel0

Returns:

  • (String)


1231
1232
1233
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1231

def custom_label0
  @custom_label0
end

#custom_label1String

Custom label 1 for custom grouping of products. Segment. Corresponds to the JSON property customLabel1

Returns:

  • (String)


1236
1237
1238
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1236

def custom_label1
  @custom_label1
end

#custom_label2String

Custom label 2 for custom grouping of products. Segment. Corresponds to the JSON property customLabel2

Returns:

  • (String)


1241
1242
1243
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1241

def custom_label2
  @custom_label2
end

#custom_label3String

Custom label 3 for custom grouping of products. Segment. Corresponds to the JSON property customLabel3

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1246

def custom_label3
  @custom_label3
end

#custom_label4String

Custom label 4 for custom grouping of products. Segment. Corresponds to the JSON property customLabel4

Returns:

  • (String)


1251
1252
1253
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1251

def custom_label4
  @custom_label4
end

#customer_country_codeString

Code of the country where the customer is located at the time of the event. Represented in the ISO 3166 format. Segment. If the customer country cannot be determined, a special 'ZZ' code is returned. Corresponds to the JSON property customerCountryCode

Returns:

  • (String)


1258
1259
1260
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1258

def customer_country_code
  @customer_country_code
end

#dateGoogle::Apis::MerchantapiReportsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



1270
1271
1272
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1270

def date
  @date
end

#impressionsFixnum

Number of times merchant's products are shown. Metric. Corresponds to the JSON property impressions

Returns:

  • (Fixnum)


1275
1276
1277
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1275

def impressions
  @impressions
end

#marketing_methodString

Marketing method to which metrics apply. Segment. Corresponds to the JSON property marketingMethod

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1280

def marketing_method
  @marketing_method
end

#offer_idString

Merchant-provided id of the product. Segment. Corresponds to the JSON property offerId

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1285

def offer_id
  @offer_id
end

#product_type_l1String

Product type (1st level) in merchant's own product taxonomy. Segment. Corresponds to the JSON property productTypeL1

Returns:

  • (String)


1292
1293
1294
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1292

def product_type_l1
  @product_type_l1
end

#product_type_l2String

Product type (2nd level) in merchant's own product taxonomy. Segment. Corresponds to the JSON property productTypeL2

Returns:

  • (String)


1299
1300
1301
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1299

def product_type_l2
  @product_type_l2
end

#product_type_l3String

Product type (3rd level) in merchant's own product taxonomy. Segment. Corresponds to the JSON property productTypeL3

Returns:

  • (String)


1306
1307
1308
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1306

def product_type_l3
  @product_type_l3
end

#product_type_l4String

Product type (4th level) in merchant's own product taxonomy. Segment. Corresponds to the JSON property productTypeL4

Returns:

  • (String)


1313
1314
1315
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1313

def product_type_l4
  @product_type_l4
end

#product_type_l5String

Product type (5th level) in merchant's own product taxonomy. Segment. Corresponds to the JSON property productTypeL5

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1320

def product_type_l5
  @product_type_l5
end

#store_typeString

Store type to which metrics apply. Can be ONLINE_STORE or LOCAL_STORES. Segment. For LOCAL_STORES store type, further segmentation by a specific store is not available. Corresponds to the JSON property storeType

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1327

def store_type
  @store_type
end

#titleString

Title of the product. Segment. Corresponds to the JSON property title

Returns:

  • (String)


1332
1333
1334
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1332

def title
  @title
end

#weekGoogle::Apis::MerchantapiReportsV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property week



1344
1345
1346
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1344

def week
  @week
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1351

def update!(**args)
  @brand = args[:brand] if args.key?(:brand)
  @category_l1 = args[:category_l1] if args.key?(:category_l1)
  @category_l2 = args[:category_l2] if args.key?(:category_l2)
  @category_l3 = args[:category_l3] if args.key?(:category_l3)
  @category_l4 = args[:category_l4] if args.key?(:category_l4)
  @category_l5 = args[:category_l5] if args.key?(:category_l5)
  @click_through_rate = args[:click_through_rate] if args.key?(:click_through_rate)
  @clicks = args[:clicks] if args.key?(:clicks)
  @conversion_rate = args[:conversion_rate] if args.key?(:conversion_rate)
  @conversion_value = args[:conversion_value] if args.key?(:conversion_value)
  @conversions = args[:conversions] if args.key?(:conversions)
  @custom_label0 = args[:custom_label0] if args.key?(:custom_label0)
  @custom_label1 = args[:custom_label1] if args.key?(:custom_label1)
  @custom_label2 = args[:custom_label2] if args.key?(:custom_label2)
  @custom_label3 = args[:custom_label3] if args.key?(:custom_label3)
  @custom_label4 = args[:custom_label4] if args.key?(:custom_label4)
  @customer_country_code = args[:customer_country_code] if args.key?(:customer_country_code)
  @date = args[:date] if args.key?(:date)
  @impressions = args[:impressions] if args.key?(:impressions)
  @marketing_method = args[:marketing_method] if args.key?(:marketing_method)
  @offer_id = args[:offer_id] if args.key?(:offer_id)
  @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1)
  @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2)
  @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3)
  @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4)
  @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5)
  @store_type = args[:store_type] if args.key?(:store_type)
  @title = args[:title] if args.key?(:title)
  @week = args[:week] if args.key?(:week)
end