Class: Google::Apis::MerchantapiReportsV1beta::ReportRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Result row returned from the search query. Only the message corresponding to the queried table is populated in the response. Within the populated message, only the fields requested explicitly in the query are populated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportRow

Returns a new instance of ReportRow.



1805
1806
1807
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_sellers_brand_viewGoogle::Apis::MerchantapiReportsV1beta::BestSellersBrandView

Fields available for query in best_sellers_brand_view table. Best sellers report with top brands. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property bestSellersBrandView



1719
1720
1721
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1719

def best_sellers_brand_view
  @best_sellers_brand_view
end

#best_sellers_product_cluster_viewGoogle::Apis::MerchantapiReportsV1beta::BestSellersProductClusterView

Fields available for query in best_sellers_product_cluster_view table. Best sellers report with top product clusters. A product cluster is a grouping for different offers and variants that represent the same product, for example, Google Pixel 7. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property bestSellersProductClusterView



1728
1729
1730
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1728

def best_sellers_product_cluster_view
  @best_sellers_product_cluster_view
end

#competitive_visibility_benchmark_viewGoogle::Apis::MerchantapiReportsV1beta::CompetitiveVisibilityBenchmarkView

Fields available for query in competitive_visibility_benchmark_view table. Competitive visibility report with the category benchmark. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property competitiveVisibilityBenchmarkView



1736
1737
1738
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1736

def competitive_visibility_benchmark_view
  @competitive_visibility_benchmark_view
end

#competitive_visibility_competitor_viewGoogle::Apis::MerchantapiReportsV1beta::CompetitiveVisibilityCompetitorView

Fields available for query in competitive_visibility_competitor_view table. Competitive visibility report with businesses with similar visibility. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property competitiveVisibilityCompetitorView



1744
1745
1746
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1744

def competitive_visibility_competitor_view
  @competitive_visibility_competitor_view
end

#competitive_visibility_top_merchant_viewGoogle::Apis::MerchantapiReportsV1beta::CompetitiveVisibilityTopMerchantView

Fields available for query in competitive_visibility_top_merchant_view table. Competitive visibility report with business with highest visibility. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property competitiveVisibilityTopMerchantView



1752
1753
1754
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1752

def competitive_visibility_top_merchant_view
  @competitive_visibility_top_merchant_view
end

#non_product_performance_viewGoogle::Apis::MerchantapiReportsV1beta::NonProductPerformanceView

Fields available for query in non_product_performance_view table. Performance data on images and online store links leading to your non-product pages. This includes performance metrics (for example, clicks) and dimensions according to which performance metrics are segmented (for example, date). Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property nonProductPerformanceView



1763
1764
1765
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1763

def non_product_performance_view
  @non_product_performance_view
end

#price_competitiveness_product_viewGoogle::Apis::MerchantapiReportsV1beta::PriceCompetitivenessProductView

Fields available for query in price_competitiveness_product_view table. Price competitiveness report. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property priceCompetitivenessProductView



1771
1772
1773
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1771

def price_competitiveness_product_view
  @price_competitiveness_product_view
end

#price_insights_product_viewGoogle::Apis::MerchantapiReportsV1beta::PriceInsightsProductView

Fields available for query in price_insights_product_view table. Price insights report. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property priceInsightsProductView



1778
1779
1780
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1778

def price_insights_product_view
  @price_insights_product_view
end

#product_performance_viewGoogle::Apis::MerchantapiReportsV1beta::ProductPerformanceView

Fields available for query in product_performance_view table. Product performance data for your account, including performance metrics (for example, clicks) and dimensions according to which performance metrics are segmented ( for example, offer_id). Values of product dimensions, such as offer_id, reflect the state of a product at the time of the impression. Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property productPerformanceView



1790
1791
1792
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1790

def product_performance_view
  @product_performance_view
end

#product_viewGoogle::Apis::MerchantapiReportsV1beta::ProductView

Fields available for query in product_view table. Products in the current inventory. Products in this table are the same as a Product resource in Products sub-API but not all product attributes from Products sub-API are available for query in this table. In contrast to Products sub-API, this table allows to filter the returned list of products by product attributes. To retrieve a single product by id or list all products, Products sub-API should be used. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property productView



1803
1804
1805
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1803

def product_view
  @product_view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1810

def update!(**args)
  @best_sellers_brand_view = args[:best_sellers_brand_view] if args.key?(:best_sellers_brand_view)
  @best_sellers_product_cluster_view = args[:best_sellers_product_cluster_view] if args.key?(:best_sellers_product_cluster_view)
  @competitive_visibility_benchmark_view = args[:competitive_visibility_benchmark_view] if args.key?(:competitive_visibility_benchmark_view)
  @competitive_visibility_competitor_view = args[:competitive_visibility_competitor_view] if args.key?(:competitive_visibility_competitor_view)
  @competitive_visibility_top_merchant_view = args[:competitive_visibility_top_merchant_view] if args.key?(:competitive_visibility_top_merchant_view)
  @non_product_performance_view = args[:non_product_performance_view] if args.key?(:non_product_performance_view)
  @price_competitiveness_product_view = args[:price_competitiveness_product_view] if args.key?(:price_competitiveness_product_view)
  @price_insights_product_view = args[:price_insights_product_view] if args.key?(:price_insights_product_view)
  @product_performance_view = args[:product_performance_view] if args.key?(:product_performance_view)
  @product_view = args[:product_view] if args.key?(:product_view)
end