Class: Google::Apis::MerchantapiReportsV1beta::SearchRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Request message for the ReportService.Search method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchRequest

Returns a new instance of SearchRequest.



1849
1850
1851
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

Optional. Number of ReportRows to retrieve in a single page. Defaults to

  1. Values above 100,000 are coerced to 100,000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1832
1833
1834
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1832

def page_size
  @page_size
end

#page_tokenString

Optional. Token of the page to retrieve. If not specified, the first page of results is returned. In order to request the next page of results, the value obtained from next_page_token in the previous response should be used. Corresponds to the JSON property pageToken

Returns:

  • (String)


1839
1840
1841
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1839

def page_token
  @page_token
end

#queryString

Required. Query that defines a report to be retrieved. For details on how to construct your query, see the Query Language guide. For the full list of available tables and fields, see the Available fields. Corresponds to the JSON property query

Returns:

  • (String)


1847
1848
1849
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1847

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1854
1855
1856
1857
1858
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1854

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @query = args[:query] if args.key?(:query)
end