Class: Google::Apis::MerchantapiReportsV1beta::StatusPerReportingContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb

Overview

Status of the product for a specific reporting context. Equivalent to DestinationStatus in Products API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatusPerReportingContext

Returns a new instance of StatusPerReportingContext.



1916
1917
1918
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#approved_countriesArray<String>

List of approved countries in the reporting context, represented in ISO 3166 format, for example, US. Corresponds to the JSON property approvedCountries

Returns:

  • (Array<String>)


1896
1897
1898
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1896

def approved_countries
  @approved_countries
end

#disapproved_countriesArray<String>

List of disapproved countries in the reporting context, represented in ISO 3166 format, for example, US. Corresponds to the JSON property disapprovedCountries

Returns:

  • (Array<String>)


1903
1904
1905
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1903

def disapproved_countries
  @disapproved_countries
end

#pending_countriesArray<String>

List of pending countries in the reporting context, represented in ISO 3166 format, for example, US. Corresponds to the JSON property pendingCountries

Returns:

  • (Array<String>)


1909
1910
1911
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1909

def pending_countries
  @pending_countries
end

#reporting_contextString

Reporting context the status applies to. Corresponds to the JSON property reportingContext

Returns:

  • (String)


1914
1915
1916
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1914

def reporting_context
  @reporting_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1921
1922
1923
1924
1925
1926
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1921

def update!(**args)
  @approved_countries = args[:approved_countries] if args.key?(:approved_countries)
  @disapproved_countries = args[:disapproved_countries] if args.key?(:disapproved_countries)
  @pending_countries = args[:pending_countries] if args.key?(:pending_countries)
  @reporting_context = args[:reporting_context] if args.key?(:reporting_context)
end