Class: Google::Apis::MerchantapiReportsV1beta::ItemIssueSeverity
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReportsV1beta::ItemIssueSeverity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb
Overview
How the issue affects the serving of the product.
Instance Attribute Summary collapse
-
#aggregated_severity ⇒ String
Aggregated severity of the issue for all reporting contexts it affects.
-
#severity_per_reporting_context ⇒ Array<Google::Apis::MerchantapiReportsV1beta::IssueSeverityPerReportingContext>
Issue severity per reporting context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ItemIssueSeverity
constructor
A new instance of ItemIssueSeverity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ItemIssueSeverity
Returns a new instance of ItemIssueSeverity.
684 685 686 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregated_severity ⇒ String
Aggregated severity of the issue for all reporting contexts it affects.
Reporting contexts included in the computation of the aggregated severity can
be restricted using a filter on the reporting_context field. This field
can be used for filtering the results.
Corresponds to the JSON property aggregatedSeverity
676 677 678 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 676 def aggregated_severity @aggregated_severity end |
#severity_per_reporting_context ⇒ Array<Google::Apis::MerchantapiReportsV1beta::IssueSeverityPerReportingContext>
Issue severity per reporting context. Reporting contexts included in this list
can be restricted using a filter on the reporting_context field.
Corresponds to the JSON property severityPerReportingContext
682 683 684 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 682 def severity_per_reporting_context @severity_per_reporting_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
689 690 691 692 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 689 def update!(**args) @aggregated_severity = args[:aggregated_severity] if args.key?(:aggregated_severity) @severity_per_reporting_context = args[:severity_per_reporting_context] if args.key?(:severity_per_reporting_context) end |