Class: Google::Apis::MerchantapiReportsV1beta::PriceCompetitivenessProductView
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReportsV1beta::PriceCompetitivenessProductView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb
Overview
Fields available for query in price_competitiveness_product_view table.
Price competitiveness
report. Values are only set for fields requested explicitly in the request's
search query.
Instance Attribute Summary collapse
-
#benchmark_price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
-
#brand ⇒ String
Brand of the product.
-
#category_l1 ⇒ String
Product category (1st level) in Google's product taxonomy.
-
#category_l2 ⇒ String
Product category (2nd level) in Google's product taxonomy.
-
#category_l3 ⇒ String
Product category (3rd level) in Google's product taxonomy.
-
#category_l4 ⇒ String
Product category (4th level) in Google's product taxonomy.
-
#category_l5 ⇒ String
Product category (5th level) in Google's product taxonomy.
-
#id ⇒ String
REST ID of the product, in the form of
channel~languageCode~feedLabel~offerId. -
#offer_id ⇒ String
Merchant-provided id of the product.
-
#price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
-
#product_type_l1 ⇒ String
Product type (1st level) in merchant's own product taxonomy.
-
#product_type_l2 ⇒ String
Product type (2nd level) in merchant's own product taxonomy.
-
#product_type_l3 ⇒ String
Product type (3rd level) in merchant's own product taxonomy.
-
#product_type_l4 ⇒ String
Product type (4th level) in merchant's own product taxonomy.
-
#product_type_l5 ⇒ String
Product type (5th level) in merchant's own product taxonomy.
-
#report_country_code ⇒ String
Country of the price benchmark.
-
#title ⇒ String
Title of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PriceCompetitivenessProductView
constructor
A new instance of PriceCompetitivenessProductView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PriceCompetitivenessProductView
Returns a new instance of PriceCompetitivenessProductView.
920 921 922 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#benchmark_price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property benchmarkPrice
825 826 827 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 825 def benchmark_price @benchmark_price end |
#brand ⇒ String
Brand of the product.
Corresponds to the JSON property brand
830 831 832 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 830 def brand @brand end |
#category_l1 ⇒ String
Product category (1st level) in Google's product taxonomy.
Corresponds to the JSON property categoryL1
836 837 838 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 836 def category_l1 @category_l1 end |
#category_l2 ⇒ String
Product category (2nd level) in Google's product taxonomy.
Corresponds to the JSON property categoryL2
842 843 844 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 842 def category_l2 @category_l2 end |
#category_l3 ⇒ String
Product category (3rd level) in Google's product taxonomy.
Corresponds to the JSON property categoryL3
848 849 850 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 848 def category_l3 @category_l3 end |
#category_l4 ⇒ String
Product category (4th level) in Google's product taxonomy.
Corresponds to the JSON property categoryL4
854 855 856 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 854 def category_l4 @category_l4 end |
#category_l5 ⇒ String
Product category (5th level) in Google's product taxonomy.
Corresponds to the JSON property categoryL5
860 861 862 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 860 def category_l5 @category_l5 end |
#id ⇒ String
REST ID of the product, in the form of channel~languageCode~feedLabel~offerId
. Can be used to join data with the product_view table. Required in the
SELECT clause.
Corresponds to the JSON property id
867 868 869 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 867 def id @id end |
#offer_id ⇒ String
Merchant-provided id of the product.
Corresponds to the JSON property offerId
872 873 874 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 872 def offer_id @offer_id end |
#price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property price
877 878 879 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 877 def price @price end |
#product_type_l1 ⇒ String
Product type (1st level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL1
883 884 885 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 883 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Product type (2nd level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL2
889 890 891 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 889 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Product type (3rd level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL3
895 896 897 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 895 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Product type (4th level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL4
901 902 903 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 901 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Product type (5th level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL5
907 908 909 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 907 def product_type_l5 @product_type_l5 end |
#report_country_code ⇒ String
Country of the price benchmark. Represented in the ISO 3166 format. Required
in the SELECT clause.
Corresponds to the JSON property reportCountryCode
913 914 915 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 913 def report_country_code @report_country_code end |
#title ⇒ String
Title of the product.
Corresponds to the JSON property title
918 919 920 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 918 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 925 def update!(**args) @benchmark_price = args[:benchmark_price] if args.key?(:benchmark_price) @brand = args[:brand] if args.key?(:brand) @category_l1 = args[:category_l1] if args.key?(:category_l1) @category_l2 = args[:category_l2] if args.key?(:category_l2) @category_l3 = args[:category_l3] if args.key?(:category_l3) @category_l4 = args[:category_l4] if args.key?(:category_l4) @category_l5 = args[:category_l5] if args.key?(:category_l5) @id = args[:id] if args.key?(:id) @offer_id = args[:offer_id] if args.key?(:offer_id) @price = args[:price] if args.key?(:price) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @report_country_code = args[:report_country_code] if args.key?(:report_country_code) @title = args[:title] if args.key?(:title) end |