Class: Google::Apis::MerchantapiReportsV1beta::ProductView
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReportsV1beta::ProductView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reports_v1beta/classes.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb,
lib/google/apis/merchantapi_reports_v1beta/representations.rb
Overview
Fields available for query in product_view table. Products in the current
inventory. Products in this table are the same as a Product resource in
Products sub-API but not all product attributes from Products
sub-API are available for query in this table. In contrast to Products sub-API,
this table allows to filter the returned list of products by product
attributes. To retrieve a single product by id or list all products,
Products sub-API should be used. Values are only set for fields requested
explicitly in the request's search query.
Instance Attribute Summary collapse
-
#aggregated_reporting_context_status ⇒ String
Aggregated status across all reporting contexts.
-
#availability ⇒ String
Availability of the product.
-
#brand ⇒ String
Brand of the product.
-
#category_l1 ⇒ String
Product category (1st level) in Google's product taxonomy.
-
#category_l2 ⇒ String
Product category (2nd level) in Google's product taxonomy.
-
#category_l3 ⇒ String
Product category (3rd level) in Google's product taxonomy.
-
#category_l4 ⇒ String
Product category (4th level) in Google's product taxonomy.
-
#category_l5 ⇒ String
Product category (5th level) in Google's product taxonomy.
-
#channel ⇒ String
Channel of the product.
-
#click_potential ⇒ String
Estimated performance potential compared to highest performing products of the merchant.
-
#click_potential_rank ⇒ Fixnum
Normalized click potential of the product.
-
#condition ⇒ String
Condition of the product.
-
#creation_time ⇒ String
The time the merchant created the product in timestamp seconds.
-
#expiration_date ⇒ Google::Apis::MerchantapiReportsV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#feed_label ⇒ String
Feed label of the product.
-
#gtin ⇒ Array<String>
List of Global Trade Item Numbers (GTINs) of the product.
-
#id ⇒ String
REST ID of the product, in the form of
channel~languageCode~feedLabel~offerId. -
#item_group_id ⇒ String
Item group id provided by the merchant for grouping variants together.
-
#item_issues ⇒ Array<Google::Apis::MerchantapiReportsV1beta::ItemIssue>
List of item issues for the product.
-
#language_code ⇒ String
Language code of the product in BCP 47 format.
-
#offer_id ⇒ String
Merchant-provided id of the product.
-
#price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
-
#product_type_l1 ⇒ String
Product type (1st level) in merchant's own product taxonomy.
-
#product_type_l2 ⇒ String
Product type (2nd level) in merchant's own product taxonomy.
-
#product_type_l3 ⇒ String
Product type (3rd level) in merchant's own product taxonomy.
-
#product_type_l4 ⇒ String
Product type (4th level) in merchant's own product taxonomy.
-
#product_type_l5 ⇒ String
Product type (5th level) in merchant's own product taxonomy.
-
#reporting_context ⇒ String
Reporting context to restrict the query to.
-
#shipping_label ⇒ String
Normalized shipping label specified in the data source.
-
#status_per_reporting_context ⇒ Array<Google::Apis::MerchantapiReportsV1beta::StatusPerReportingContext>
Detailed product status per reporting context.
-
#thumbnail_link ⇒ String
Link to the processed image of the product, hosted on the Google infrastructure.
-
#title ⇒ String
Title of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductView
constructor
A new instance of ProductView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductView
Returns a new instance of ProductView.
1666 1667 1668 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregated_reporting_context_status ⇒ String
Aggregated status across all reporting contexts. Reporting contexts included
in the computation of the aggregated status can be restricted using a filter
on the reporting_context field.
Corresponds to the JSON property aggregatedReportingContextStatus
1475 1476 1477 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1475 def aggregated_reporting_context_status @aggregated_reporting_context_status end |
#availability ⇒ String
Availability of the
product.
Corresponds to the JSON property availability
1481 1482 1483 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1481 def availability @availability end |
#brand ⇒ String
Brand of the product.
Corresponds to the JSON property brand
1486 1487 1488 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1486 def brand @brand end |
#category_l1 ⇒ String
Product category (1st level) in Google's product taxonomy.
Corresponds to the JSON property categoryL1
1492 1493 1494 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1492 def category_l1 @category_l1 end |
#category_l2 ⇒ String
Product category (2nd level) in Google's product taxonomy.
Corresponds to the JSON property categoryL2
1498 1499 1500 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1498 def category_l2 @category_l2 end |
#category_l3 ⇒ String
Product category (3rd level) in Google's product taxonomy.
Corresponds to the JSON property categoryL3
1504 1505 1506 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1504 def category_l3 @category_l3 end |
#category_l4 ⇒ String
Product category (4th level) in Google's product taxonomy.
Corresponds to the JSON property categoryL4
1510 1511 1512 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1510 def category_l4 @category_l4 end |
#category_l5 ⇒ String
Product category (5th level) in Google's product taxonomy.
Corresponds to the JSON property categoryL5
1516 1517 1518 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1516 def category_l5 @category_l5 end |
#channel ⇒ String
Channel of the product. Can be ONLINE or LOCAL.
Corresponds to the JSON property channel
1521 1522 1523 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1521 def channel @channel end |
#click_potential ⇒ String
Estimated performance potential compared to highest performing products of the
merchant.
Corresponds to the JSON property clickPotential
1527 1528 1529 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1527 def click_potential @click_potential end |
#click_potential_rank ⇒ Fixnum
Normalized click potential of the product. Values range from 1 to 1000, where
1 is the highest click potential and 1000 is the theoretical lowest.
Corresponds to the JSON property clickPotentialRank
1533 1534 1535 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1533 def click_potential_rank @click_potential_rank end |
#condition ⇒ String
Condition of the
product.
Corresponds to the JSON property condition
1539 1540 1541 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1539 def condition @condition end |
#creation_time ⇒ String
The time the merchant created the product in timestamp seconds.
Corresponds to the JSON property creationTime
1544 1545 1546 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1544 def creation_time @creation_time end |
#expiration_date ⇒ Google::Apis::MerchantapiReportsV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property expirationDate
1556 1557 1558 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1556 def expiration_date @expiration_date end |
#feed_label ⇒ String
Feed label of the product.
Corresponds to the JSON property feedLabel
1561 1562 1563 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1561 def feed_label @feed_label end |
#gtin ⇒ Array<String>
List of Global Trade Item Numbers (GTINs) of the product.
Corresponds to the JSON property gtin
1566 1567 1568 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1566 def gtin @gtin end |
#id ⇒ String
REST ID of the product, in the form of channel~languageCode~feedLabel~offerId
. Merchant API methods that operate on products take this as their name
parameter. Required in the SELECT clause.
Corresponds to the JSON property id
1573 1574 1575 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1573 def id @id end |
#item_group_id ⇒ String
Item group id provided by the merchant for grouping variants together.
Corresponds to the JSON property itemGroupId
1578 1579 1580 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1578 def item_group_id @item_group_id end |
#item_issues ⇒ Array<Google::Apis::MerchantapiReportsV1beta::ItemIssue>
List of item issues for the product. This field cannot be used for sorting
the results. Only selected attributes of this field (for example,
item_issues.severity.aggregated_severity) can be used for filtering the
results.
Corresponds to the JSON property itemIssues
1586 1587 1588 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1586 def item_issues @item_issues end |
#language_code ⇒ String
Language code of the product in BCP 47 format.
Corresponds to the JSON property languageCode
1591 1592 1593 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1591 def language_code @language_code end |
#offer_id ⇒ String
Merchant-provided id of the product.
Corresponds to the JSON property offerId
1596 1597 1598 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1596 def offer_id @offer_id end |
#price ⇒ Google::Apis::MerchantapiReportsV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property price
1601 1602 1603 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1601 def price @price end |
#product_type_l1 ⇒ String
Product type (1st level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL1
1607 1608 1609 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1607 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Product type (2nd level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL2
1613 1614 1615 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1613 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Product type (3rd level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL3
1619 1620 1621 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1619 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Product type (4th level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL4
1625 1626 1627 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1625 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Product type (5th level) in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL5
1631 1632 1633 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1631 def product_type_l5 @product_type_l5 end |
#reporting_context ⇒ String
Reporting context to restrict the query to. Restricts the reporting contexts
returned in status_per_reporting_context and item_issues, and used to
compute aggregated_reporting_context_status. This field can only be used
in the WHERE clause and cannot be selected in the SELECT clause.
Corresponds to the JSON property reportingContext
1639 1640 1641 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1639 def reporting_context @reporting_context end |
#shipping_label ⇒ String
Normalized shipping label specified in the data source.
Corresponds to the JSON property shippingLabel
1645 1646 1647 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1645 def shipping_label @shipping_label end |
#status_per_reporting_context ⇒ Array<Google::Apis::MerchantapiReportsV1beta::StatusPerReportingContext>
Detailed product status per reporting context. Reporting contexts included in
this list can be restricted using a filter on the reporting_context field.
Equivalent to ProductStatus.destination_statuses in Products API. This
field cannot be used for sorting or filtering the results.
Corresponds to the JSON property statusPerReportingContext
1653 1654 1655 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1653 def status_per_reporting_context @status_per_reporting_context end |
#thumbnail_link ⇒ String
Link to the processed image of the product, hosted on the Google
infrastructure.
Corresponds to the JSON property thumbnailLink
1659 1660 1661 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1659 def thumbnail_link @thumbnail_link end |
#title ⇒ String
Title of the product.
Corresponds to the JSON property title
1664 1665 1666 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1664 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 |
# File 'lib/google/apis/merchantapi_reports_v1beta/classes.rb', line 1671 def update!(**args) @aggregated_reporting_context_status = args[:aggregated_reporting_context_status] if args.key?(:aggregated_reporting_context_status) @availability = args[:availability] if args.key?(:availability) @brand = args[:brand] if args.key?(:brand) @category_l1 = args[:category_l1] if args.key?(:category_l1) @category_l2 = args[:category_l2] if args.key?(:category_l2) @category_l3 = args[:category_l3] if args.key?(:category_l3) @category_l4 = args[:category_l4] if args.key?(:category_l4) @category_l5 = args[:category_l5] if args.key?(:category_l5) @channel = args[:channel] if args.key?(:channel) @click_potential = args[:click_potential] if args.key?(:click_potential) @click_potential_rank = args[:click_potential_rank] if args.key?(:click_potential_rank) @condition = args[:condition] if args.key?(:condition) @creation_time = args[:creation_time] if args.key?(:creation_time) @expiration_date = args[:expiration_date] if args.key?(:expiration_date) @feed_label = args[:feed_label] if args.key?(:feed_label) @gtin = args[:gtin] if args.key?(:gtin) @id = args[:id] if args.key?(:id) @item_group_id = args[:item_group_id] if args.key?(:item_group_id) @item_issues = args[:item_issues] if args.key?(:item_issues) @language_code = args[:language_code] if args.key?(:language_code) @offer_id = args[:offer_id] if args.key?(:offer_id) @price = args[:price] if args.key?(:price) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @reporting_context = args[:reporting_context] if args.key?(:reporting_context) @shipping_label = args[:shipping_label] if args.key?(:shipping_label) @status_per_reporting_context = args[:status_per_reporting_context] if args.key?(:status_per_reporting_context) @thumbnail_link = args[:thumbnail_link] if args.key?(:thumbnail_link) @title = args[:title] if args.key?(:title) end |